@@ -79,14 +79,19 @@ struct _WnckScreenClass
   /* app gone */
   void (* application_closed)       (WnckScreen      *screen,
                                      WnckApplication *app);
-  
+
+  /* New background */
+  void (* background_changed)       (WnckScreen      *screen);
 };
 
 GType wnck_screen_get_type (void) G_GNUC_CONST;
 
+WnckScreen* wnck_screen_get_default (void);
 WnckScreen* wnck_screen_get (int index);
 WnckScreen* wnck_screen_get_for_root (gulong root_window_id);
 
+WnckWorkspace* wnck_screen_get_workspace        (WnckScreen *screen,
+						 int         workspace);
 WnckWorkspace* wnck_screen_get_active_workspace (WnckScreen *screen);
 WnckWindow*    wnck_screen_get_active_window    (WnckScreen *screen);
 
@@ -100,6 +105,19 @@ int wnck_screen_get_workspace_count (WnckScreen *screen);
 gboolean wnck_screen_net_wm_supports (WnckScreen *screen,
                                       const char *atom);
 
+gulong wnck_screen_get_background_pixmap (WnckScreen *screen);
+
+int wnck_screen_get_width (WnckScreen *screen);
+int wnck_screen_get_height (WnckScreen *screen);
+
+int  wnck_screen_try_set_workspace_layout (WnckScreen *screen,
+                                           int         current_token,
+                                           int         rows,
+                                           int         columns);
+void wnck_screen_release_workspace_layout (WnckScreen *screen,
+                                           int         current_token);
+
+
 G_END_DECLS
 
 #endif /* WNCK_SCREEN_H */
